==> haskell-data-accessor-template-0.2.1.13-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-template
version: 0.2.1.13
id: data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
key: data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Utilities for accessing and manipulating fields of records
description:
    Automate generation of @Accessor@'\''s of the @data-accessor@ package
    by Template Haskell functions.
category: Data
author: Luke Palmer <lrpalmer@gmail.com>,
        Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Accessor.Template
hidden-modules: Data.Accessor.Template.Example
abi: 12d5b62057f9d8d38f1982c46b446081
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.13
data-dir: /usr/share/i386-linux-ghc-8.0.1/data-accessor-template-0.2.1.13
hs-libraries: HSdata-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
depends:
    base-4.9.0.0 data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    template-haskell-2.11.0.0 utility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
haddock-interfaces: /usr/share/doc/haskell-data-accessor-template/html/data-accessor-template.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-template-0.2.1.13-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-template
version: 0.2.1.13
id: data-accessor-template-0.2.1.13-9rU3hJ3Wexf6m7EcZLYdbr
key: data-accessor-template-0.2.1.13-9rU3hJ3Wexf6m7EcZLYdbr
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Utilities for accessing and manipulating fields of records
description:
    Automate generation of @Accessor@'\''s of the @data-accessor@ package
    by Template Haskell functions.
category: Data
author: Luke Palmer <lrpalmer@gmail.com>,
        Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Accessor.Template
hidden-modules: Data.Accessor.Template.Example
abi: 3bb35685622aa6970bd3115981836e0d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-template-0.2.1.13
data-dir: /usr/share/i386-linux-ghc-8.0.1/data-accessor-template-0.2.1.13
hs-libraries: HSdata-accessor-template-0.2.1.13-9rU3hJ3Wexf6m7EcZLYdbr
depends:
    base-4.9.0.0 data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    template-haskell-2.11.0.0 utility-ht-0.0.13-6LFtwAy4r2q397pbhjrZza
haddock-interfaces: /usr/share/doc/haskell-data-accessor-template/html/data-accessor-template.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
